@@ -40,6 +40,11 @@ Brazil <- R6::R6Class("Brazil",
     ),
     #' @field source_data_cols existing columns within the raw data
     source_data_cols = c("cases_total", "deaths_total"),
+    #' @field source_text Plain text description of the source of the data
+    source_text = "Wesley Cota",
+    #' @field source_url Website address for explanation/introduction of the
+    #' data
+    source_url = "https://github.com/wcota/covid19br/blob/master/README.en.md",
 
     #' @description Set up a table of region codes for clean data
     #' @importFrom tibble tribble
