@@ -29,9 +29,6 @@ France <- R6::R6Class("France",
     supported_region_names = list("1" = "region", "2" = "department"),
     #' @field supported_region_codes A list of region codes in order of level.
     supported_region_codes = list("1" = "iso_3166_2", "2" = "ons_region_code"),
-    #' @field common_data_urls List of named links to raw data. This is empty
-    #' as for France data is divided into cases by level
-    common_data_urls = list(),
     # nolint start
     #' @field level_data_urls List of named links to raw data that are level
     #' specific.
@@ -45,6 +42,12 @@ France <- R6::R6Class("France",
     # nolint end
     #' @field source_data_cols existing columns within the raw data
     source_data_cols = c("cases_new", "tested_new"),
+    #' @field source_text Plain text description of the source of the data
+    source_text = "French Public Open Data Platform",
+    #' @field source_url Website address for explanation/introduction of the
+    #' data
+    source_url = "https://www.data.gouv.fr/fr/pages/donnees-coronavirus",
+
 
     #' @description Set up a table of region codes for clean data
     #' @importFrom tibble tibble
