@@ -154,6 +154,12 @@ Lithuania <- R6::R6Class("Lithuania",
     source_data_cols = c(
       "cases_new", "tested_new", "recovered_total", "deaths_new"
     ),
+    #' @field source_text Plain text description of the source of the data
+    source_text = "Lithuanian Statistics Department",
+    #' @field source_url Website address for explanation/introduction of the
+    #' data
+    source_url = "https://hub.arcgis.com/datasets/d49a63c934be4f65a93b6273785a8449_0/about", # nolint
+
     # Additional attributes specific to the Lithuania functionality
     #' @field death_definition which criteria of deaths attributed to
     #' COVID to use
@@ -408,11 +414,11 @@ Lithuania <- R6::R6Class("Lithuania",
                           recovered_definition = "official",
                           all_osp_fields = FALSE,
                           national_data = FALSE, ...) {
-      super$initialize(...)
       self$death_definition <- death_definition
       self$recovered_definition <- recovered_definition
       self$all_osp_fields <- all_osp_fields
       self$national_data <- national_data
+      super$initialize(...)
     }
   )
 )
