@@ -47,6 +47,11 @@ Mexico <- R6::R6Class("Mexico",
     ),
     #' @field source_data_cols existing columns within the raw data
     source_data_cols = c("cases_new", "deaths_new"),
+    #' @field source_text Plain text description of the source of the data
+    source_text = "Government of Mexico",
+    #' @field source_url Website address for explanation/introduction of the
+    #' data
+    source_url = "https://datos.covid-19.conacyt.mx",
 
     #' @description Set up a table of region codes for clean data
     #' @importFrom tibble tibble
