@@ -32,9 +32,6 @@ USA <- R6::R6Class("USA",
       "1" = "iso_3166_2",
       "2" = "fips"
     ),
-    #' @field common_data_urls List of named links to raw data. Since there are
-    #'  no common data sources for level 1 and 2, this list is empty.
-    common_data_urls = list(),
     #' @field level_data_urls List of named links to raw data that are level
     #' specific.
     # nolint start
@@ -45,6 +42,11 @@ USA <- R6::R6Class("USA",
     # nolint end
     #' @field source_data_cols existing columns within the raw data
     source_data_cols = c("cases_total", "deaths_total"),
+    #' @field source_text Plain text description of the source of the data
+    source_text = "New York Times",
+    #' @field source_url Website address for explanation/introduction of the
+    #' data
+    source_url = "https://github.com/nytimes/covid-19-data",
 
     #' @description Set up a table of region codes for clean data
     #' @importFrom tibble tribble
