@@ -9,7 +9,8 @@ test_that(
     expected_names <- c(
       "origin", "class", "level_1_region",
       "level_2_region", "level_3_region", "type",
-      "data_urls", "source_data_cols"
+      "data_urls", "source_data_cols",
+      "source_text", "source_url"
     )
     expect_identical(colnames(data), expected_names)
   }
@@ -41,7 +42,13 @@ test_that(
 
 # test each column for na values
 for (name in colnames(data)) {
-  if (name %in% c("level_1_region", "level_2_region", "level_3_region")) {
+  if (name %in% c(
+    "level_1_region",
+    "level_2_region",
+    "level_3_region",
+    "source_text",
+    "source_url"
+  )) {
     next
   }
   test_that(
@@ -63,3 +70,21 @@ test_that("National level datasets can be filtered for", {
   expect_equal(nrow(dplyr::filter(nat, class %in% "Italy")), 0)
   expect_equal(unique(nat$type), "national")
 })
+
+test_that(
+  paste(
+    "all_country_data is up to date.",
+    "This will fail if a new data source has been added, or an existing one",
+    "modified, but the table outlining available data (all_country_data) has",
+    "not been re-rendered. Run the code in",
+    "data-raw/render_available_datasets.R to update all_country_data"
+  ),
+  {
+    package_avaliable_data <- get_available_datasets()
+    rendered_available_data <- get_available_datasets(render = TRUE)
+    expect_identical(
+      package_avaliable_data,
+      rendered_available_data
+    )
+  }
+)
